@@ -1,7 +1,5 @@
 from typing import Any, Dict, List, Optional, Tuple, cast
 
-import httpx
-
 from httpx_oauth.errors import GetIdEmailError
 from httpx_oauth.oauth2 import BaseOAuth2
 
@@ -11,7 +9,21 @@ BASE_SCOPES = ["User.Read"]
 PROFILE_ENDPOINT = "https://graph.microsoft.com/v1.0/me"
 
 
+LOGO_SVG = """
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<svg width="100%" height="100%" viewBox="0 0 110 110" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" xml:space="preserve" xmlns:serif="http://www.serif.com/" style="fill-rule:evenodd;clip-rule:evenodd;stroke-linejoin:round;stroke-miterlimit:2;">
+    <rect x="0" y="0" width="51.927" height="51.927" style="fill:rgb(241,81,27);fill-rule:nonzero;"/>
+    <rect x="57.334" y="0" width="51.926" height="51.927" style="fill:rgb(128,204,40);fill-rule:nonzero;"/>
+    <rect x="0" y="57.354" width="51.925" height="51.927" style="fill:rgb(0,173,239);fill-rule:nonzero;"/>
+    <rect x="57.334" y="57.354" width="51.926" height="51.927" style="fill:rgb(251,188,9);fill-rule:nonzero;"/>
+</svg>
+"""
+
+
 class MicrosoftGraphOAuth2(BaseOAuth2[Dict[str, Any]]):
+    display_name = "Microsoft"
+    logo_svg = LOGO_SVG
+
     def __init__(
         self,
         client_id: str,
